==> ftindexmanagement-portlet-2.1.0-20130703.041354-16-sources.jar: org/gcube/portlets/admin/fulltextindexportlet/gwt/client/FTIndexManagementPortlet.java <==
package org.gcube.portlets.admin.fulltextindexportlet.gwt.client;

import org.gcube.portlets.admin.fulltextindexportlet.gwt.client.interfaces.ManagementService;
import org.gcube.portlets.admin.fulltextindexportlet.gwt.client.interfaces.ManagementServiceAsync;
import org.gcube.portlets.admin.fulltextindexportlet.gwt.client.ui.indexmanagement.index.AddIndexPanel;
import org.gcube.portlets.admin.fulltextindexportlet.gwt.client.ui.indexmanagement.index.IndexDetail;
import org.gcube.portlets.admin.fulltextindexportlet.gwt.client.ui.intextypemanagement.IndexTypeEditorPanel;

import com.google.gwt.core.client.EntryPoint;
import com.google.gwt.core.client.GWT;
import com.google.gwt.dom.client.Element;
import com.google.gwt.dom.client.NodeList;
import com.google.gwt.user.client.Command;
import com.google.gwt.user.client.DeferredCommand;
import com.google.gwt.user.client.Window;
import com.google.gwt.user.client.WindowResizeListener;
import com.google.gwt.user.client.rpc.ServiceDefTarget;
import com.google.gwt.user.client.ui.HorizontalSplitPanel;
import com.google.gwt.user.client.ui.RootPanel;
import com.google.gwt.user.client.ui.TabPanel;
import com.google.gwt.user.client.ui.TreeItem;
import com.google.gwt.user.client.ui.TreeListener;
import com.google.gwt.user.client.ui.VerticalPanel;

/**
 * Entry point class for the FullTextIndexPortlet application.
 */
public class FTIndexManagementPortlet implements EntryPoint, WindowResizeListener, TreeListener {

	/** An GWT RPC interface to the ManagementService */
	public static ManagementServiceAsync mgmtService = (ManagementServiceAsync) GWT.create(ManagementService.class);

	/**
	 * A panel to hold the index information and manipulation panels on the
	 * right side of the screen
	 */
	private VerticalPanel indexPanel;

	/** A panel to hold the panels used to administer a chosen index */
	private IndexDetail indexDetail;

	/** A panel to hold the panels used to administer a chosen lookup */
//	private LookupDetail lookupDetail;

	/** A panel used to add an index */
	private AddIndexPanel addIndexPanel;

	/** A panel used to add a lookup */
	//private AddLookupPanel addLookupPanel;

	private TabPanel mainTabPanel = new TabPanel();

	private IndexTypeEditorPanel idxTypePanel;

	/**
	 * {@inheritDoc}
	 */
	public void onModuleLoad() {
		ServiceDefTarget mgmtEndpoint = (ServiceDefTarget) mgmtService;
		mgmtEndpoint.setServiceEntryPoint(GWT.getModuleBaseURL() + "/MgmtService");

//		ServiceDefTarget lookupEndpoint = (ServiceDefTarget) lookupService;
//		lookupEndpoint.setServiceEntryPoint(GWT.getModuleBaseURL() + "/LookupService");

		try {
			IndexExplorer explorer = new IndexExplorer(this);

			indexPanel = new VerticalPanel();
			indexDetail = new IndexDetail();
			indexDetail.setVisible(false);
//			lookupDetail = new LookupDetail();
//			lookupDetail.setVisible(false);

			addIndexPanel = new AddIndexPanel();
			addIndexPanel.setVisible(false);
			addIndexPanel.addItemAddedListener(explorer);

//			addLookupPanel = new AddLookupPanel();
//			addLookupPanel.setVisible(false);
//			addLookupPanel.addItemAddedListener(explorer);

			indexPanel.add(indexDetail);
			//indexPanel.add(lookupDetail);
			indexPanel.add(addIndexPanel);
//			indexPanel.add(addLookupPanel);
			indexDetail.addItemRemovedListener(explorer);
		//lookupDetail.addItemRemovedListener(explorer);

			idxTypePanel = new IndexTypeEditorPanel();
			HorizontalSplitPanel outer = new HorizontalSplitPanel();
			outer.setSize("99%", "450px");
			outer.setLeftWidget(explorer);
			outer.setRightWidget(indexPanel);

			NodeList<Element> nl = mainTabPanel.getElement().getElementsByTagName("div");
			for (int i=0; i<nl.getLength(); i++) {
				Element n = nl.getItem(i);
				if (n.getClassName().contains("gwt-TabPanelBottom"))
					n.getStyle().setPropertyPx("height", 467);
			}

			mainTabPanel.setWidth("100%");
			mainTabPanel.setHeight("500px");
			mainTabPanel.add(outer, "Index manager");
			mainTabPanel.add(idxTypePanel, "IndexType manager");
			mainTabPanel.selectTab(0);

			RootPanel.get("FullTextIndexManager").add(mainTabPanel);
			indexPanel.setWidth("100%");
			indexDetail.setWidth("100%");
			//lookupDetail.setWidth("100%");

			Window.addWindowResizeListener(this);

			DeferredCommand.addCommand(new Command() {
				public void execute() {
					onWindowResized(Window.getClientWidth(), Window
							.getClientHeight());
				}
			});
		} catch (Exception e) {
			Window.alert(e.getMessage());
			e.printStackTrace();
		}
	}

	/**
	 * {@inheritDoc}
	 */
	public void onWindowResized(int width, int height) {
		// int categoriesHeight = height - categories.getAbsoluteTop() - 8;
		// if (categoriesHeight < 1){
		// categoriesHeight = 1;
		// }
		// categories.setHeight("" + categoriesHeight);
		//
		// indexDetail.setWidth("" + (width - indexDetail.getAbsoluteLeft() -
		// 25));
	}

	/**
	 * {@inheritDoc}
	 */
	public void onTreeItemSelected(TreeItem item) {
		if (item instanceof IndexExplorer.IndexTreeItem) {
		//	lookupDetail.setVisible(false);
			indexDetail.setVisible(true);
			addIndexPanel.setVisible(false);
	//		addLookupPanel.setVisible(false);
			indexDetail.updateDetail(((IndexExplorer.IndexTreeItem) item)
					.getIndexID());
//		} else if (item instanceof IndexExplorer.LookupTreeItem) {
//			String idxID = ((IndexExplorer.LookupTreeItem) item).getIndexID();
//			int connID = ((IndexExplorer.LookupTreeItem) item)
//			.getConnectionID();
//			indexDetail.setVisible(false);
//			lookupDetail.setVisible(true);
//			addIndexPanel.setVisible(false);
//			addLookupPanel.setVisible(false);
//			lookupDetail.updateDetail(idxID, connID);
		} else if (item instanceof IndexExplorer.AdditionTreeItem) {
			IndexExplorer.AdditionTreeItem addItem = (IndexExplorer.AdditionTreeItem) item;
			if (addItem.getType().equals(
					IndexExplorer.AdditionTreeItem.COLLECTION)) {
				addIndexPanel.update(null);
				addIndexPanel.setVisible(true);
	//			addLookupPanel.setVisible(false);
			} else if (addItem.getType().equals(
					IndexExplorer.AdditionTreeItem.INDEX)) {
				// TODO changed the input to null
				addIndexPanel.update(null);
				//addIndexPanel.update(addItem.getParentItem().getText().
					//	substring(0, addItem.getParentItem().getText().indexOf(' ')));
				addIndexPanel.setVisible(true);
		//		addLookupPanel.setVisible(false);
//			} else if (addItem.getType().equals(
//					IndexExplorer.AdditionTreeItem.LOOKUP)) {
//				addLookupPanel.update(addItem.getParentItem().getText());
//				addLookupPanel.setVisible(true);
//				addIndexPanel.setVisible(false);
			}
			indexDetail.setVisible(false);
			//lookupDetail.setVisible(false);
		} else {
			indexDetail.setVisible(false);
			//lookupDetail.setVisible(false);
			addIndexPanel.setVisible(false);
		}
	}

	/**
	 * {@inheritDoc}
	 */
	public void onTreeItemStateChanged(TreeItem item) {
	}
}

==> ftindexmanagement-portlet-2.1.1-20130726.144519-3-sources.jar: org/gcube/portlets/admin/fulltextindexportlet/gwt/client/FTIndexManagementPortlet.java <==
package org.gcube.portlets.admin.fulltextindexportlet.gwt.client;

import org.gcube.portlets.admin.fulltextindexportlet.gwt.client.interfaces.ManagementService;
import org.gcube.portlets.admin.fulltextindexportlet.gwt.client.interfaces.ManagementServiceAsync;
import org.gcube.portlets.admin.fulltextindexportlet.gwt.client.ui.indexmanagement.index.AddIndexPanel;
import org.gcube.portlets.admin.fulltextindexportlet.gwt.client.ui.indexmanagement.index.IndexDetail;
import org.gcube.portlets.admin.fulltextindexportlet.gwt.client.ui.intextypemanagement.IndexTypeEditorPanel;

import com.google.gwt.core.client.EntryPoint;
import com.google.gwt.core.client.GWT;
import com.google.gwt.dom.client.Element;
import com.google.gwt.dom.client.NodeList;
import com.google.gwt.user.client.Command;
import com.google.gwt.user.client.DeferredCommand;
import com.google.gwt.user.client.Window;
import com.google.gwt.user.client.WindowResizeListener;
import com.google.gwt.user.client.rpc.ServiceDefTarget;
import com.google.gwt.user.client.ui.HorizontalSplitPanel;
import com.google.gwt.user.client.ui.RootPanel;
import com.google.gwt.user.client.ui.TabPanel;
import com.google.gwt.user.client.ui.TreeItem;
import com.google.gwt.user.client.ui.TreeListener;
import com.google.gwt.user.client.ui.VerticalPanel;

/**
 * Entry point class for the FullTextIndexPortlet application.
 */
public class FTIndexManagementPortlet implements EntryPoint, WindowResizeListener, TreeListener {

	/** An GWT RPC interface to the ManagementService */
	public static ManagementServiceAsync mgmtService = (ManagementServiceAsync) GWT.create(ManagementService.class);

	/**
	 * A panel to hold the index information and manipulation panels on the
	 * right side of the screen
	 */
	private VerticalPanel indexPanel;

	/** A panel to hold the panels used to administer a chosen index */
	private IndexDetail indexDetail;

	/** A panel used to add an index */
	private AddIndexPanel addIndexPanel;

	private TabPanel mainTabPanel = new TabPanel();

	private IndexTypeEditorPanel idxTypePanel;

	/**
	 * {@inheritDoc}
	 */
	public void onModuleLoad() {
		ServiceDefTarget mgmtEndpoint = (ServiceDefTarget) mgmtService;
		mgmtEndpoint.setServiceEntryPoint(GWT.getModuleBaseURL() + "/MgmtService");

		try {
			IndexExplorer explorer = new IndexExplorer(this);

			indexPanel = new VerticalPanel();
			indexDetail = new IndexDetail();
			indexDetail.setVisible(false);

			addIndexPanel = new AddIndexPanel();
			addIndexPanel.setVisible(false);
			addIndexPanel.addItemAddedListener(explorer);

			indexPanel.add(indexDetail);
			indexPanel.add(addIndexPanel);
			indexDetail.addItemRemovedListener(explorer);

			idxTypePanel = new IndexTypeEditorPanel();
			HorizontalSplitPanel outer = new HorizontalSplitPanel();
			outer.setSize("99%", "450px");
			outer.setLeftWidget(explorer);
			outer.setRightWidget(indexPanel);

			NodeList<Element> nl = mainTabPanel.getElement().getElementsByTagName("div");
			for (int i=0; i<nl.getLength(); i++) {
				Element n = nl.getItem(i);
				if (n.getClassName().contains("gwt-TabPanelBottom"))
					n.getStyle().setPropertyPx("height", 467);
			}

			mainTabPanel.setWidth("100%");
			mainTabPanel.setHeight("500px");
			mainTabPanel.add(outer, "Index manager");
			mainTabPanel.add(idxTypePanel, "IndexType manager");
			mainTabPanel.selectTab(0);

			RootPanel.get("FullTextIndexManager").add(mainTabPanel);
			indexPanel.setWidth("100%");
			indexDetail.setWidth("100%");
		
			Window.addWindowResizeListener(this);

			DeferredCommand.addCommand(new Command() {
				public void execute() {
					onWindowResized(Window.getClientWidth(), Window
							.getClientHeight());
				}
			});
		} catch (Exception e) {
			Window.alert(e.getMessage());
			e.printStackTrace();
		}
	}

	/**
	 * {@inheritDoc}
	 */
	public void onWindowResized(int width, int height) {

	}

	/**
	 * {@inheritDoc}
	 */
	public void onTreeItemSelected(TreeItem item) {
		if (item instanceof IndexExplorer.IndexTreeItem) {
			indexDetail.setVisible(true);
			addIndexPanel.setVisible(false);
			indexDetail.updateDetail(((IndexExplorer.IndexTreeItem) item).getIndexID(), ((IndexExplorer.IndexTreeItem) item).getRelatedCollectionID());
		} else if (item instanceof IndexExplorer.AdditionTreeItem) {
			IndexExplorer.AdditionTreeItem addItem = (IndexExplorer.AdditionTreeItem) item;
			if (addItem.getType().equals(
					IndexExplorer.AdditionTreeItem.COLLECTION)) {
				addIndexPanel.update(null);
				addIndexPanel.setVisible(true);
			} else if (addItem.getType().equals(
					IndexExplorer.AdditionTreeItem.INDEX)) {
				// TODO changed the input to null
				addIndexPanel.update(null);
				addIndexPanel.setVisible(true);
			}
			indexDetail.setVisible(false);
		} else {
			indexDetail.setVisible(false);
			addIndexPanel.setVisible(false);
		}
	}

	/**
	 * {@inheritDoc}
	 */
	public void onTreeItemStateChanged(TreeItem item) {
	}
}
